@@ -8,6 +8,8 @@ from ._doc import TypedDoc as TypedDoc
 from ._map import Map as Map
 from ._map import MapEvent as MapEvent
 from ._map import TypedMap as TypedMap
+from ._provider import Channel as Channel
+from ._provider import Provider as Provider
 from ._pycrdt import StackItem as StackItem
 from ._pycrdt import SubdocsEvent as SubdocsEvent
 from ._pycrdt import Subscription as Subscription
